.. _index:

Phasor Noise documentation |version|
=====================================

.. |br| raw:: html

   <br />

.. toctree::
   :maxdepth: 2

   getting_started/index
   user_guide/index
   api/index

Introduction
------------

This project is an engineering school project of la Prepa des INP Nancy. |br|
5 students own this project:

* Alexis le Meur
* Etienne Tachouzin
* Paul Bedrossian
* Guillaume Hisleur
* Paul Martin

About the project
-----------------
Phasor noise is a package providing a generator of procedural phasor noise. |br|
It claims a graphical interface to visualize how parameters change the noise created.
